C----------------------------------------------------------------------
C     Anjoint scaled eigenfunction of the cycle in the 3D food chain
C
C     PAR(12)=log(FM)
C     PAR(13)=square norm of the eigenfunction at T=0
C---------------------------------------------------------------------- 
C 
      SUBROUTINE FUNC(NDIM,U,ICP,PAR,IJAC,F,DFDU,DFDP) 
C     ---------- ---- 
      IMPLICIT DOUBLE PRECISION (A-Z) 
      DIMENSION U(NDIM),PAR(*),F(NDIM)
      DIMENSION A(3,3)
C     Variables
      x=U(1)
      y=U(2)
      z=U(3)
C     Parameters
      d1=PAR(1)
      d2=PAR(2)
      a1 = 5.
      a2 = 0.1
      b1 = 3.
      b2 = 2.
C      f_1=(a_1*x_1)/(1. + b_1*x_1)
C      f_2=(a_2*x_2)/(1. + b_2*x_2)
C     Functions
      F(1)=x*(1.0-x) - a1*x*y/(1.0+b1*x)
      F(2)=a1*x*y/(1.0+b1*x) - d1*y - a2*y*z/(1.0+b2*y)
      F(3)=a2*y*z/(1.0+b2*y) - d2*z
C     Jacobian elements
      A(1,1)=0.1D1-2*x-a1*y/(0.1D1+b1*x)+a1*x*y/(1.0+b1*x)**2*b1
      A(1,2)=-a1*x/(1.0+b1*x)
      A(1,3)=0.0
      A(2,1)=a1*y/(1.0+b1*x)-a1*x*y/(1.0+b1*x)**2*b1
      A(2,2)=a1*x/(1.0+b1*x)-d1-a2*z/(1.0+b2*y)+a2*y*z/(1.0+b2*y)**2*b2
      A(2,3)=-a2*y/(1.0+b2*y)
      A(3,1)=0.0
      A(3,2)=a2*z/(1.0+b2*y)-a2*y*z/(1.0+b2*y)**2*b2
      A(3,3)=a2*y/(1.0+b2*y)-d2
C
      F(4) = - A(1,1)*U(4) - A(2,1)*U(5) - A(3,1)*U(6)
      F(5) = - A(1,2)*U(4) - A(2,2)*U(5) - A(3,2)*U(6) 
      F(6) = - A(1,3)*U(4) - A(2,3)*U(5) - A(3,3)*U(6)
C     
      F(1) = PAR(11)*F(1)
      F(2) = PAR(11)*F(2)
      F(3) = PAR(11)*F(3)
      F(4) = PAR(11)*F(4)-PAR(12)*U(4)
      F(5) = PAR(11)*F(5)-PAR(12)*U(5)
      F(6) = PAR(11)*F(6)-PAR(12)*U(6)
C     
      RETURN 
      END 
C
      SUBROUTINE STPNT
      RETURN 
      END 
C 
      SUBROUTINE BCND(NDIM,PAR,ICP,NBC,U0,U1,FB,IJAC,DBC) 
C     ---------- ---- 
C 
      IMPLICIT DOUBLE PRECISION (A-Z) 
      DIMENSION PAR(*),ICP(*),U0(NDIM),U1(NDIM),FB(NBC)
C
C     Periodicity boundary conditions 
C     -------------------------------
C    
      FB(1) = U0(1) - U1(1)
      FB(2) = U0(2) - U1(2)
      FB(3) = U0(3) - U1(3)
C
      FB(4) = U1(4) - U0(4)
      FB(5) = U1(5) - U0(5)
      FB(6) = U1(6) - U0(6)
C     
      FB(7) = U0(4)**2 + U0(5)**2 + U0(6)**2 - PAR(13)
C
      RETURN 
      END 
C 
      SUBROUTINE ICND(NDIM,PAR,ICP,NINT,U,UOLD,UDOT,UPOLD,FI,IJAC,DINT) 
C     ---------- ---- 
C 
      IMPLICIT DOUBLE PRECISION (A-Z) 
      DIMENSION U(NDIM),UOLD(NDIM),UDOT(NDIM),UPOLD(NDIM) 
      DIMENSION FI(NINT),DINT(NINT,*),ICP(*),PAR(*) 
C
C     Integral phase condition 
C     ------------------------
      FI(1) = U(1)*UPOLD(1)+U(2)*UPOLD(2)+U(3)*UPOLD(3)
C
      RETURN 
      END 
C
      SUBROUTINE FOPT 
      RETURN 
      END 
C 
      SUBROUTINE PVLS
      RETURN 
      END 
