C----------------------------------------------------------------------
C     Anjoint scaled eigenfunction of the cycle in the 3D food chain
C
C     PAR(12)=log(FM)
C     PAR(13)=square norm of the eigenfunction at T=0
C---------------------------------------------------------------------- 
C 
      SUBROUTINE FUNC(NDIM,U,ICP,PAR,IJAC,F,DFDU,DFDP) 
C     ---------- ---- 
      IMPLICIT DOUBLE PRECISION (A-Z) 
      DIMENSION U(NDIM),PAR(*),F(NDIM)
      DIMENSION A(3,3)
C     Variables
      x=U(1)
      y=U(2)
      z=U(3)
C     Parameters
      d1=PAR(1)
      d2=PAR(2)
      a1 = 5.
      a2 = 0.1
      b1 = 3.
      b2 = 2.
C      f_1=(a_1*x_1)/(1. + b_1*x_1)
C      f_2=(a_2*x_2)/(1. + b_2*x_2)
C     Functions
      F(1)=x*(1.0-x) - a1*x*y/(1.0+b1*x)
      F(2)=a1*x*y/(1.0+b1*x) - d1*y - a2*y*z/(1.0+b2*y)
      F(3)=a2*y*z/(1.0+b2*y) - d2*z
C     Jacobian elements
      A(1,1)=0.1D1-2*x-a1*y/(0.1D1+b1*x)+a1*x*y/(1.0+b1*x)**2*b1
      A(1,2)=-a1*x/(1.0+b1*x)
      A(1,3)=0.0
      A(2,1)=a1*y/(1.0+b1*x)-a1*x*y/(1.0+b1*x)**2*b1
      A(2,2)=a1*x/(1.0+b1*x)-d1-a2*z/(1.0+b2*y)+a2*y*z/(1.0+b2*y)**2*b2
      A(2,3)=-a2*y/(1.0+b2*y)
      A(3,1)=0.0
      A(3,2)=a2*z/(1.0+b2*y)-a2*y*z/(1.0+b2*y)**2*b2
      A(3,3)=a2*y/(1.0+b2*y)-d2
C
      F(4) = - A(1,1)*U(4) - A(2,1)*U(5) - A(3,1)*U(6)
      F(5) = - A(1,2)*U(4) - A(2,2)*U(5) - A(3,2)*U(6) 
      F(6) = - A(1,3)*U(4) - A(2,3)*U(5) - A(3,3)*U(6)
C     
      F(1) = PAR(11)*F(1)
      F(2) = PAR(11)*F(2)
      F(3) = PAR(11)*F(3)
      F(4) = PAR(11)*F(4)-PAR(12)*U(4)
      F(5) = PAR(11)*F(5)-PAR(12)*U(5)
      F(6) = PAR(11)*F(6)-PAR(12)*U(6)
C     Functions
      F(7)=U(7)*(1.0-U(7)) - a1*U(7)*U(8)/(1.0+b1*U(7))
      F(8)=a1*U(7)*U(8)/(1.0+b1*U(7)) 
     *- d1*U(8) - a2*U(8)*U(9)/(1.0+b2*U(8))
      F(9)=a2*U(8)*U(9)/(1.0+b2*U(8)) - d2*U(9)
C      
      F(7) = PAR(13)*F(7)
      F(8) = PAR(13)*F(8)
      F(9) = PAR(13)*F(9)
C     
      RETURN 
      END 
C
      SUBROUTINE STPNT(NDIM,U,PAR)
C     ---------- ----- 
C     
      IMPLICIT DOUBLE PRECISION (A-Z)
      DIMENSION U(NDIM),PAR(*)
      DIMENSION U0(9),U1(9)
C     Parameters
      PAR(1)=0.25
      PAR(2)=0.0125
C     Equilibrium
      PAR(4)=0.7415816238
      PAR(5)=0.1666666667
      PAR(6)=11.99773243
C     Adjoint stable eigenvector
      PAR(7)=0.0984409966
      PAR(8)=0.1687707747
      PAR(9)=0.004953226984
C     Normalized
      PAR(7)=0.5036762705
      PAR(8)=0.8635206602
      PAR(9)=0.02534333236
C     Normalisation eigenvector
      normv=SQRT(PAR(7)*PAR(7)+PAR(8)*PAR(8)+PAR(9)*PAR(9))
      PAR(7)=PAR(7)/normv
      PAR(8)=PAR(8)/normv
      PAR(9)=PAR(9)/normv
C     Lambda
      PAR(10)=-0.4259111656
C     Cycle period
      PAR(11)=2.4282250177E+01
C     Log Floquet multiplier
      PAR(12)=-4.3996108530E-01
C     Truncated time interval
      PAR(13)=1.7245438540E+02
C     c1     
      PAR(14)=7.53646E-01
C     c2
      PAR(15)=6.57280E-01
C     homotopy h2
      U0(1)=8.3979157213E-01      
      U0(2)=1.2527681887E-01
      U0(3)=1.0552891520E+01
      U0(4)=9.3062780166E-02    
      U0(5)=-8.7791301849E-01
      U0(6)=-4.6968931318E-01
      U1(7)=8.9563892570E-01      
      U1(8)=7.5142309014E-02
      U1(9)=1.0306391261E+01
    
      h1=(U1(7)-U0(1))
      h2=(U1(8)-U0(2))
      h3=(U1(9)-U0(3))

      PAR(16) = U0(4)*h1 + U0(5)*h2 + U0(6)*h3

C     epsilon
      PAR(17)=0.001
C
      RETURN 
      END 
C 
      SUBROUTINE BCND(NDIM,PAR,ICP,NBC,U0,U1,FB,IJAC,DBC) 
C     ---------- ---- 
C 
      IMPLICIT DOUBLE PRECISION (A-Z) 
      DIMENSION PAR(*),ICP(*),U0(NDIM),U1(NDIM),FB(NBC)
      DIMENSION A(3,3)
C     Fixed parameters
      a1 = 5.
      a2 = 0.1
      b1 = 3.
      b2 = 2.
C     Parameters
      d1=PAR(1)
      d2=PAR(2)
C     Variables
      x=PAR(4)
      y=PAR(5)
      z=PAR(6)
C     Eigenvectors
      v1=PAR(7)
      v2=PAR(8)
      v3=PAR(9)
C     Eigenvalues
      lambda=PAR(10)
C     Jacobian elements
      A(1,1)=0.1D1-2*x-a1*y/(0.1D1+b1*x)+a1*x*y/(1.0+b1*x)**2*b1
      A(1,2)=-a1*x/(1.0+b1*x)
      A(1,3)=0.0
      A(2,1)=a1*y/(1.0+b1*x)-a1*x*y/(1.0+b1*x)**2*b1
      A(2,2)=a1*x/(1.0+b1*x)-d1-a2*z/(1.0+b2*y)+a2*y*z/(1.0+b2*y)**2*b2
      A(2,3)=-a2*y/(1.0+b2*y)
      A(3,1)=0.0
      A(3,2)=a2*z/(1.0+b2*y)-a2*y*z/(1.0+b2*y)**2*b2
      A(3,3)=a2*y/(1.0+b2*y)-d2
C     Equilibrium
      FB(1) = x*(1.0-x) - a1*x*y/(1.0+b1*x)
      FB(2) = a1*x*y/(1.0+b1*x) - d1*y - a2*y*z/(1.0+b2*y)
      FB(3) = a2*y*z/(1.0+b2*y) - d2*z
C     Boundary conditions limit cycle
      FB(4) = U0(1) - U1(1)
      FB(5) = U0(2) - U1(2)
      FB(6) = U0(3) - U1(3)   
      FB(7) = U1(4) - U0(4)
      FB(8) = U1(5) - U0(5)
      FB(9) = U1(6) - U0(6)
C     Eigenfunction normalisation
      FB(10) = v1*v1 + v2*v2 + v3*v3 - 1.0
      FB(11) = U0(4)*U0(4) + U0(5)*U0(5) + U0(6)*U0(6) - 1.0
C     Adjoint stable vector
      FB(12) = A(1,1)*v1+A(2,1)*v2+A(3,1)*v3-lambda*v1
      FB(13) = A(1,2)*v1+A(2,2)*v2+A(3,2)*v3-lambda*v2
      FB(14) = A(1,3)*v1+A(2,3)*v2+A(3,3)*v3-lambda*v3
C     Displacement from the cycle 
      h1=(U1(7)-U0(1))
      h2=(U1(8)-U0(2))
      h3=(U1(9)-U0(3))
C
      h4=(U0(7)-x)
      h5=(U0(8)-y)
      h6=(U0(9)-z)
C     Eqn. (25a)
      epsilon=PAR(17)
C     Eq. (25a)
      c1=PAR(14)
      c2=PAR(15)
      FB(15) = U0(7)-x-epsilon*c1*v2
      FB(16) = U0(8)-y+epsilon*c1*v1-epsilon*c2*v3
      FB(17) = U0(9)-z+epsilon*c2*v2
C
      g1=U0(1)*(1.0-U0(1)) - a1*U0(1)*U0(2)/(1.0+b1*U0(1))
      g2=a1*U0(1)*U0(2)/(1.0+b1*U0(1))
     *- d1*U0(2) - a2*U0(2)*U0(3)/(1.0+b2*U0(3))
      g3=a2*U0(2)*U0(3)/(1.0+b2*U0(2)) - d2*U0(3)
C     Eq. (24h)
      FB(18) = h1*g1 + h2*g2 + h3*g3 
C     Eq. (24c)
      FB(19) = U0(4)*h1 + U0(5)*h2 + U0(6)*h3 - PAR(16)
C     Eq. (25b)
      FB(20) = c1**2 + c2**2 - 1.0
C
      RETURN 
      END 
C 
      SUBROUTINE ICND(NDIM,PAR,ICP,NINT,U,UOLD,UDOT,UPOLD,FI,IJAC,DINT) 
C     ---------- ---- 
C 
      IMPLICIT DOUBLE PRECISION (A-Z) 
      DIMENSION U(NDIM),UOLD(NDIM),UDOT(NDIM),UPOLD(NDIM) 
      DIMENSION FI(NINT),DINT(NINT,*),ICP(*),PAR(*) 
C
C     Integral phase condition 
C     ------------------------
C      FI(1)=UPOLD(7)*(U(7)-UOLD(7)) + UPOLD(8)*(U(8)-UOLD(8))
C     *  + UPOLD(9)*(U(9)-UOLD(9))
C
      RETURN 
      END 
C
      SUBROUTINE FOPT 
      RETURN 
      END 
C 
      SUBROUTINE PVLS
      RETURN 
      END 
