
C----------------------------------------------------------------------
C     Point-to-cycle connection in the food chain model
C----------------------------------------------------------------------
C 
      SUBROUTINE RHS(N,U,PAR,R,DRDX) 
C     ---------- ---- 
C     
      IMPLICIT DOUBLE PRECISION (A-Z) 
      DIMENSION U(N),PAR(*),R(N),DRDX(N,N)
C
C     Variables
      x=U(1)
      y=U(2)
      z=U(3)
C     Parameters
      a1=PAR(1)
      a2=PAR(2)
      b1=PAR(3)
      b2=PAR(4)
      d1=PAR(5)
      d2=PAR(6)
C
C     RHS
      R(1)=x*(1.0-x) - a1*x*y/(1.0+b1*x)
      R(2)=a1*x*y/(1.0+b1*x) - d1*y - a2*y*z/(1.0+b2*y)
      R(3)=a2*y*z/(1.0+b2*y) - d2*z
C
C     Jacobian elements
      DRDX(1,1)=0.1D1-2*x-a1*y/(0.1D1+b1*x) 
     * +a1*x*y/(1.0+b1*x)**2*b1
      DRDX(1,2)=-a1*x/(1.0+b1*x)
      DRDX(1,3)=0.0
      DRDX(2,1)=a1*y/(1.0+b1*x)-a1*x*y/(1.0+b1*x)**2*b1
      DRDX(2,2)=a1*x/(1.0+b1*x)-d1-a2*z/(1.0+b2*y)
     * +a2*y*z/(1.0+b2*y)**2*b2
      DRDX(2,3)=-a2*y/(1.0+b2*y)
      DRDX(3,1)=0.0
      DRDX(3,2)=a2*z/(1.0+b2*y)-a2*y*z/(1.0+b2*y)**2*b2
      DRDX(3,3)=a2*y/(1.0+b2*y)-d2
C
      RETURN
      END
C    
      SUBROUTINE FUNC(NDIM,U,ICP,PAR,IJAC,F,DFDU,DFDP) 
C     ---------- ---- 
C     
      IMPLICIT DOUBLE PRECISION (A-Z) 
      DIMENSION U(NDIM),PAR(*),F(NDIM)     
      DIMENSION X(3),R(3),A(3,3)
C     Variables
C     U(1)-U(3) = limit cycle
C     U(4)-U(6) = adjoint eigenfunction 
C     U(7)-U(9) = connecting orbit 
C     Cycle equations
      N=3
      X(1)=U(1)
      X(2)=U(2)
      X(3)=U(3)
      CALL RHS(N,X,PAR,R,A) 
      F(1)=R(1)
      F(2)=R(2)
      F(3)=R(3)
C     Adjoint variational equations
C     PAR(11) = cycle period
C     PAR(12) = log(FM) 
      F(4) = -A(1,1)*U(4) - A(2,1)*U(5) - A(3,1)*U(6)
      F(5) = -A(1,2)*U(4) - A(2,2)*U(5) - A(3,2)*U(6) 
      F(6) = -A(1,3)*U(4) - A(2,3)*U(5) - A(3,3)*U(6)
      F(1) = PAR(11)*F(1)
      F(2) = PAR(11)*F(2)
      F(3) = PAR(11)*F(3)
      F(4) = PAR(11)*F(4)-PAR(12)*U(4)
      F(5) = PAR(11)*F(5)-PAR(12)*U(5)
      F(6) = PAR(11)*F(6)-PAR(12)*U(6)
C     Connecting orbit equations
      X(1)=U(7)
      X(2)=U(8)
      X(3)=U(9)
      CALL RHS(N,X,PAR,R,A) 
      F(7)=R(1)
      F(8)=R(2)
      F(9)=R(3)
C     PAR(13) = connection interval     
      F(7) = PAR(13)*F(7)
      F(8) = PAR(13)*F(8)
      F(9) = PAR(13)*F(9)
C
      RETURN 
      END 
C     
      SUBROUTINE STPNT(NDIM,U,PAR)
C     ---------- ----- 
C     
      IMPLICIT DOUBLE PRECISION (A-Z)
      DIMENSION U(NDIM),PAR(*)
C     System parameters
      a1=5.0
      a2=0.1
      b1=3.0
      b2=2.0
      d1=0.25
      d2=0.0125
C
      PAR(1)=a1
      PAR(2)=a2
      PAR(3)=b1
      PAR(4)=b2
      PAR(5)=d1
      PAR(6)=d2
C
C     Cycle period
      PAR(11)=2.4282250177E+01 
C     Log Floquet multiplier 
      PAR(12)=-4.3996108530E-01
C     Connection time
      PAR(13)=1.7245438540E+02
C
C     Equilibrium coordinates 	       
      PAR(14)=7.4158162381E-01
      PAR(15)=1.6666666666E-01
      PAR(16)=1.1997732011E+01
C
C     Normalized adjoint eigenvector of the equilibrium
      PAR(17)=0.5036762705
      PAR(18)=0.8635206602
      PAR(19)=0.02534333236
C            
C     Stable eigenvalue
      PAR(20)=-0.4259111656
C 
      PAR(21)= 8.314799514E-07
   
      RETURN 
      END 
C     
      SUBROUTINE BCND(NDIM,PAR,ICP,NBC,U0,U1,FB,IJAC,DBC) 
C     ---------- ---- 
C     
      IMPLICIT DOUBLE PRECISION (A-Z) 
      DIMENSION PAR(*),ICP(*),U0(NDIM),U1(NDIM),FB(NBC)
      DIMENSION X(3),R(3),A(3,3)
C
      N=3  
C     Periodic boundary conditions 
C     Cycle     
      FB(1)  = U0(1) - U1(1)
      FB(2)  = U0(2) - U1(2)
      FB(3)  = U0(3) - U1(3) 
C     Scaled eigenfunction   
      FB(4)  = U1(4) - U0(4)
      FB(5)  = U1(5) - U0(5)
      FB(6)  = U1(6) - U0(6)
C     Eigenfunction normalisation
      FB(7) = U0(4)**2 + U0(5)**2 + U0(6)**2 - 1.0d0
C     Projection boundary condition at the endpoint
      h1=U1(7)-U0(1)
      h2=U1(8)-U0(2)
      h3=U1(9)-U0(3)
      FB(8) = h1*U0(4) + h2*U0(5) + h3*U0(6)
C     Connection endpoint in the orthogonal plane to velocity
      X(1)=U0(1)
      X(2)=U0(2)
      X(3)=U0(3)
      CALL RHS(N,X,PAR,R,A)
      FB(9) = h1*R(1) + h2*R(2) + h3*R(3)
C     Equilibrium coordinates
      X(1)=PAR(14)
      X(2)=PAR(15)
      X(3)=PAR(16)
      CALL RHS(N,X,PAR,R,A) 
      FB(10) = R(1)
      FB(11) = R(2)
      FB(12) = R(3)
C     Adjoint eigenvector
      v1=PAR(17)
      v2=PAR(18)
      v3=PAR(19)
C     Stable eigenvalue
      lambda=PAR(20)
C      
      FB(13)= A(1,1)*v1+A(2,1)*v2+A(3,1)*v3-lambda*v1
      FB(14)= A(1,2)*v1+A(2,2)*v2+A(3,2)*v3-lambda*v2
      FB(15)= A(1,3)*v1+A(2,3)*v2+A(3,3)*v3-lambda*v3
C      
C     Adjoint vector normalization
      FB(16) = v1**2 + v2**2 + v3**2 - 1.0d0
C 
      g1=U0(7)-PAR(14)
      g2=U0(8)-PAR(15)
      g3=U0(9)-PAR(16)

C     Projection BC at the starting point 
      FB(17)=g1*v1+g2*v2+g3*v3
C     
C     Distance to the equilibrium
      FB(18)=g1**2+g2**2+g3**2-PAR(21)
      
      RETURN 
      END 
C 
      SUBROUTINE ICND(NDIM,PAR,ICP,NINT,U,UOLD,UDOT,UPOLD,FI,IJAC,DINT) 
      RETURN 
      END 
C
      SUBROUTINE FOPT 
      RETURN 
      END 
C 
      SUBROUTINE PVLS
      RETURN 
      END
